import { UserCard } from "@/components/cards/UserCard";
import { EmailClassificationCard } from "@/components/cards/authifier/EmailClassificationCard";
import { NavigationToolbar } from "@/components/common/NavigationToolbar";
import { AccountActions } from "@/components/inspector/AccountActions";
import { fetchAccountById, fetchUserById } from "@/lib/db";
import { notFound } from "next/navigation";
import { User } from "revolt-api";

export default async function User({
  params,
}: {
  params: { id: string; type: string };
}) {
  const account = await fetchAccountById(params.id);
  if (!account) return notFound();

  const user = await fetchUserById(params.id);

  return (
    <div className="flex flex-col gap-2">
      <NavigationToolbar>Inspecting Account</NavigationToolbar>
      {user && <UserCard user={user} subtitle={account.email} />}
      <AccountActions account={account} user={user as User} />
      <EmailClassificationCard email={account.email} />
      {/*TODO? update password, reset 2FA, disable / undisable (disabled if pending
      delete), delete / cancel delete
      <br />
      list active 2FA methods without keys
      <br />
      email account*/}
    </div>
  );
}
